<?php
/*
 Plugin Name: wp-back2future
 Plugin URI: http://another.maple4ever.net/
 Description: アップロードディレクトリを指定日付にパッチします。
 Version: 1.00
 Author: hiromasa
 Author URI: http://another.maple4ever.net/
 */

/*  Copyright 2009 hiromasa (email : h1romas4@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/******************************************************************************
 * WpBack2Future - WordPress Interface Define
 *****************************************************************************/

if(!(defined('ABSPATH') && defined('WPINC'))) return;

/******************************************************************************
 * WpBack2Future
 *
 * @author		hiromasa
 * @version		1.00
 *
 *****************************************************************************/
class WpBack2Future {
	
	var $options;
	
	/**
	 * WpBack2Future
	 *
	 * @return WpBack2Future
	 */
	function WpBack2Future() {
		
		$this->options = get_option('wp-back2future');
		//initialize option first time
		if(empty($this->options)) {
			$this->options['enabled'] = false;
			$this->options['patchdir'] = '2009/04';
			update_option('wp-back2future', $this->options);
		}
		
	}
	
	/**
	 * patch
	 *
	 * @param unknown_type $upload_dir
	 * @return unknown
	 */
	function patch($uploads) {
		
		if($this->options['enabled'] == false) return $uploads;
		
		$patch = $this->options['patchdir'];
		
		$uploads['path'] = 
			str_replace($uploads['subdir'], '', $uploads['path']) . '/' . $patch;
		$uploads['url'] = 
			str_replace($uploads['subdir'], '', $uploads['url']) . '/' . $patch;
		$uploads['subdir'] = '/' . $patch;
		
		return $uploads;
		
	}
	
	/**
	 * Define WordPress Admin Interface
	 *
	 */
	function addAdminMenu() {
		
		add_options_page(
			'Back2Future',
			'Back2Future',
			'manage_options',
			basename(__FILE__),
			array (&$this, 'executeAdmin')
		);
		
	}
	
	/**
	 * Execute WordPress Admin Interface
	 *
	 */
	function executeAdmin() {
		
		$message = array();
		
		$newoptions = get_option('wp-back2future');
		if (isset($_POST["action"])) {
			$newoptions['enabled'] = $_POST["enabled"] != '' ? true : false;
			$newoptions['patchdir'] = strip_tags(stripslashes($_POST["patchdir"]));
		}
		if ( $this->options != $newoptions ) {
			$this->options = $newoptions;
			update_option('wp-back2future', $this->options);
			array_push($message, 'オプションを更新しました。');
		}
		
		$upload_dir = wp_upload_dir();
		$enabled = $this->options['enabled'] == true ? 'checked' : '';
		$patchdir = attribute_escape($this->options['patchdir']);
		
		$this->echoAdminHeader();
		
		if(count($message) != 0) {
			$this->echoMessage($message);
		}
		
		echo '<table class="form-table">' . "\n";
		
		echo '<tr valign="top">' . "\n";
		echo '<th scope="row"><label for="patch">現在のアップロードディレクトリ</label></th>' . "\n";
		echo '<td>';
		echo "{$upload_dir['path']}\n";
		echo '</td>' . "\n";
		echo '</tr>' . "\n";
				
		echo '<tr valign="top">' . "\n";
		echo '<th scope="row"><label for="patch">パッチを有効にする</label></th>' . "\n";
		echo '<td>';
		echo '<input name="enabled" type="checkbox" id="enabled" style="vertical-align: text-bottom;"';
		echo " {$enabled} />\n";
		echo '</td>' . "\n";
		echo '</tr>' . "\n";
		
		echo '<tr valign="top">' . "\n";
		echo '<th scope="row"><label for="patchdir">パッチ日付（サブディレクトリ）</label></th>' . "\n";
		echo '<td>';
		echo "<input name=\"patchdir\" type=\"text\" id=\"patchdir\" value=\"{$patchdir}\" size=\"40\" />\n";
		echo '</td>' . "\n";
		echo '</tr>' . "\n";
		
		echo '</table>' . "\n";
		echo '<p class="submit">' . "\n";
		echo '<input type="submit" name="Submit" value="Save Changes" />' . "\n";
		echo '</p>' . "\n";
		
		$this->echoAdminFooter();
		
	}
	
	/**
	 * echoAdminHeader
	 *
	 */
	function echoAdminHeader() {
		
		echo '<div class="wrap">' . "\n";;
		echo '<h2>Back2Future</h2>' . "\n";
		echo '<form method="post">' . "\n";
		
	}
	
	/**
	 * echoAdminFooter
	 *
	 */
	function echoAdminFooter() {
		
		echo '<input type="hidden" name="action" id="action" value="update" />' . "\n";
		echo '</form>';
		echo '</div><!-- wrap -->';
		
	}
	
	/**
	 * outputValue
	 *
	 * @param unknown_type $value
	 * @param unknown_type $echo
	 * @param unknown_type $escape
	 * @return unknown
	 */
	function outputValue($value, $echo = true, $escape = true) {
		
		$result = stripslashes($value);
		if($escape) {
			$result = attribute_escape($value);
		}
		if($echo) {
			echo $result;
		}
		return $result;
		
	}
	
	/**
	 * echoMessage
	 *
	 * @param unknown_type $messages
	 */
	function echoMessage($messages) {
		
		if(count($messages) == 0) return;
		
		$information = '';
		foreach($messages as $message) {
			$information .= '<p><strong>'
				. $this->outputValue($message, false)
				. '</strong></p>' . "\n";
		}
		
		echo '<div id="message" class="updated fade">' . "\n";
		echo $this->outputValue($information, false, false);
		echo '</div>' . "\n";
		
	}
	
}

/******************************************************************************
 * WpBack2Future - WordPress Interface Define
 *****************************************************************************/

$wpb2f = new WpBack2Future();

add_filter('upload_dir', array(&$wpb2f, 'patch'));

if(is_admin()) {
	add_action('admin_menu', array (&$wpb2f, 'addAdminMenu'));
}
?>